@@ -7,6 +7,7 @@ from urllib import error, parse, request
 # projects
 ################################
 def list_projects(url: str, api_key: str) -> Any:
+    """GET /projects.[format]"""
     try:
         params = {
             "key": api_key
@@ -24,6 +25,7 @@ def list_projects(url: str, api_key: str) -> Any:
 
 
 def show_project() -> None:
+    """GET /projects/[id].[format]"""
     pass
 
 
@@ -42,6 +44,7 @@ def show_user() -> None:
 # issues
 ################################
 def list_issues(url: str, api_key: str, project: str) -> Any:
+    """GET /issues.[format]"""
     try:
         params = {
             "key": api_key,
@@ -61,5 +64,20 @@ def list_issues(url: str, api_key: str, project: str) -> Any:
         return
 
 
-def show_issue() -> None:
-    pass
+def show_issue(url: str, api_key: str, id: str) -> Any:
+    """GET /issues/[id].[format]"""
+    try:
+        params = {
+            "key": api_key,
+        }
+
+        req = request.Request(f"{url}/issues/{id}.json?{parse.urlencode(params)}")
+
+        with request.urlopen(req) as res:
+            return json.load(res)
+    except error.HTTPError as err:
+        print(err.code)
+        return
+    except error.URLError as err:
+        print(err.reason)
+        return
